function model = demo3D18()
%demo3D18
%
% Trains a generative model of the framework using the holefinding
% functionality

% Created: Ivan E. Cao-Berg
%
% Copyright (C) 2013 Murphy Lab
% Lane Center for Computational Biology
% School of Computer Science
% Carnegie Mellon University
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published
% by the Free Software Foundation; either version 2 of the License,
% or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
% 02110-1301, USA.
%
% For additional information visit http://murphylab.web.cmu.edu or
% send email to murphy@cmu.edu
    
curr_path = which('demo3D18.m');
curr_path = curr_path(1:end-10);
cd(curr_path);

zipfile = 'cellorganizer_demo_3D3T3.zip';
url = ['http://murphylab.web.cmu.edu/data/3D/3T3' filesep zipfile ];
directory = [ pwd filesep 'jarvik_3D_3T3'];

if ~exist( [pwd filesep zipfile] )
    disp('Downloading dataset');
    urlwrite( url, zipfile );
    disp('Extracting files');
    unzip( zipfile );
else
    disp('Dataset found on disk. Extracting files from existing zipfile');
    if ~exist( [ pwd filesep directory ] );
        unzip( zipfile );
    else
        disp( 'Folder found, skipping unzipping.');
    end
end

%move all the crop images to their own directory
imdir = [ pwd filesep '/jarvik_3D_3T3/'];
cropdir = [imdir 'masks/'];
if ~exist(cropdir, 'dir')
    mkdir(cropdir)
end

files = dir([imdir filesep '*.tif']);

for i = 1:length(files)
    if strfind(files(i).name, 'crop')
        movefile([imdir files(i).name], cropdir)
    end
end

cell = [imdir '*.tif'];
crop = [cropdir '*.tif'];

dimensionality = '3D';
param.verbose = true;
param.debug = true;
% param.downsample = [10, 0.25, 0.25];
param.train.flag = 'framework';
param.model.downsampling = [8, 8, 0];
param.display = false;
param.masks = crop;

model = img2model(dimensionality, [], cell, [], param);
save('model.mat', 'model')

end

