function [imfunc, minwinsize] = get_diffeo_image_function(param)
%grj 7/25/13 Image function for Taraz's diffeomorphic model for CO
%grj 8/14/13 ability to perform only on dna segmentations, and some
%            image registration
%grj 8/29/13 Added a temp file, so we dont have to load and rotate all the
%            images to find the large bounding box
% Aug 30, 2013 G. Johnson    Changed they way files are input into the
%                            diffeomorphic model function
    
    tempdir = param.model.diffeomorphic.tempdir;
    
    preprocfiles = dir([param.preprocessingFolder filesep 'cell*.mat']);
    preprocfiles = sort_nat({preprocfiles.name});
    
    if ~exist( tempdir )
	   mkdir( tempdir )
    end

    imfuncparams_file = [tempdir filesep 'imfunc_params.mat'];
    numimgs = length(preprocfiles);
    
    
    if ~exist(imfuncparams_file, 'file')
        
        c = 1;
        sizes = zeros(numimgs, 3);
        for i = 1:numimgs
            fname = [param.preprocessingFolder filesep preprocfiles{i}];

            img = cellfile2registeredimg(fname);

            if ~isempty(img)
                imsize = size(img);

                %Add extra zeros on the end incase the image is not 3D -grj
                sizes(c,:) = [imsize, ones(1,3 - length(imsize))];
                c = c+1;
            else
                sizes(end,:) = [];
            end
        end

        
        maxsize = max(sizes,[],1);
        maxsize(1:2) = max(maxsize(1:2));

        minsize = min(sizes,[],1);
        minsize(1:2) = max(minsize(1:2));
        
        minwinsize = ceil(maxsize(1) / ceil(maxsize(1)/minsize(1)));
        
        minwinsize = [minwinsize, minwinsize, minsize(3)];
        
        maxwinsize = maxsize;
        
        save(imfuncparams_file, 'minwinsize', 'maxwinsize');
    else
        load(imfuncparams_file)
    end
    
    imfunc = @(x) diff_img_function(x, param.preprocessingFolder, maxwinsize);
%     imnumfunc = @(x) im_num_function(x, preprocfiles);
end

function [img] = diff_img_function(filenum, parentdir, maxsize)
    %this function
%     load(cellfiles{filenum})
    
    fname = [parentdir filesep 'cell' num2str(filenum) '.mat'];
    
    img = cellfile2registeredimg(fname);
    
    if ~isempty(img)
        imsize = size(img);



        pad = (maxsize - imsize) ./ 2;

        img = padarray(img, floor(pad), 0, 'both');

        img = padarray(img, double(~(floor(pad) == pad)), 0, 'pre');
        img = double(img);
    end
    
end

function img = cellfile2registeredimg(fname)
    if ~exist(fname, 'file')
        img = [];
        return
    end
    
    
    load(fname)
    
    img = zeros(size(segdna));

    boundimg = segdna;
    
    if exist('segcell', 'var')
        img(segcell>0) = 1; 
        boundimg = segdna + segcell;
    end

    imbounds = true(size(segdna));
    imbounds(2:end-1,2:end-1,:) = 0;
    
    if isempty(segdna) | all(~segdna(:)) | any(boundimg(imbounds(:)))
        img = [];
        return
    end

    img(segdna>0) = 2;

    %             angle = rad2deg(ml_majorangle(img)) %% this doesn't seem to work right now

    angle = regionprops(sum(img,3)>0, 'orientation');
    angle = angle.Orientation;
    imrot = imrotate(img, -angle);

    %             figure, imshow(sum(imrot,3),[])
    %rotate and crop the image to figure out how big it is
    imrot = pc12_cropImg(imrot, 5);

    imsize = size(imrot);

%     %Center the image in the frame by the location of the nucleus
%     nuccent = round(ml_objcenter(imrot>1));
% 
%    

    %sometimes there are disconnected regions. In practice they are quite
    %small and we ignore them
     regions = regionprops(imrot>0);
     [~, objind] = max([regions(:).Area]);
     
     nuccent = round(regions(objind).Centroid );

     nuccent(1:2) = nuccent(2:-1:1);

    offset = round(size(imrot) - nuccent*2);

    for j = 1:length(offset)
        pad = zeros(1, length(imsize));
        pad(j) = abs(offset(j));
        if offset == 0
            continue
        elseif offset > 0
            str = 'pre';
        else
            str = 'post';
        end
        imrot = padarray(imrot, pad, str);
    end
    
    img = imrot;
end
