function makeFrame(model,options,curr_point,framefolder,currframe)
%Moved from model2diffeomorphicInstance.m
%This code generates a single frame from a diffeomorphic shape space model.
%Inputs: 
% model - a cellorganizer diffeomorphic model
% options - the set of options for synthesizing from a trained shape space
% model
% curr_point - the location in the shape space to synthesize
% framefolder - the location to save the resulting image
% currframe - the index of the current frame for book keeping.
%
%Outputs:
%Saves .tif files for cell and nuclear shape in the framefolder
%Save a .mat file containing the cells willmore energy
%

%Created by:
%Taraz Buck
%Moved to its own function by:
%Devin Sullivan 7/22/13
%
%Edited by: 
%D. Sullivan 9/6/13 - supressed warnings for willmore energy calculation
%D. Sullivan 9/12/13 - added check if result files were present to skip
%interpolation. 


celldir = [framefolder filesep 'Cellwalk'];
if ~isdir(celldir)
    mkdir(celldir);
end
nucdir = [framefolder filesep 'Nucwalk'];
if ~isdir(nucdir)
    mkdir(nucdir);
end
edir = [framefolder filesep 'energies'];
if ~isdir(edir)
    mkdir(edir);
end

cellframe = [celldir filesep 'frame' num2str(currframe) '.tif'];
nucframe = [nucdir filesep 'frame' num2str(currframe) '.tif'];
eframe = [edir filesep 'walkinfo' num2str(currframe) '.mat'];


if exist(cellframe,'file')&&exist(nucframe,'file')
    disp('Cell and Nuclear interpolations found. Skipping recalculation.')
    if exist(eframe,'file')
        return
    else
        energy = AverageEnergy(cellimg);
        save(eframe,'energy');
        return
    end
end
    


frame = generate_frame_from_trained_shape_space_model(model, curr_point, options );

%icaoberg 10/8/2012
%imwrite(reshape_contrast(round(frame.interpolated_image.get_data())), image_filename)
img = reshape_contrast(round(frame.interpolated_image.get_data()));
img = reshape( img, size(img,1), size(img,1), [] );

%tebuck 11/5/2012
%the variable image must contain three unique values: 0 for background, 1 for cell and
%2 for nucleus, i.e. img is an indexed image

values = unique( img );
nucimg = zeros( size(img) );
nucimg(find(img == values(3))) = 255;


cellimg = zeros( size(img) );
%icaoberg 11/5/2012
cellimg(find(img == values(2))) = 255 ;

%D. Sullivan 6/27/13 - added Willmore energy tracking so we can
%directly observe the cell energy for the current frame
%         energy(i) = AverageEnergy(frame{i}.interpolated_image.image{1});
%D. Sullivan 9/6/13 suppressed warnings for this step
warning('off','all')
energy = AverageEnergy(cellimg);
warning('on','all')

%D. Sullivan 2/25/13 need to remove the padding zeros from the
%framework model maintaining a 1 slice padding (this is for converting
%to meshing if needed later.
keepslices = find(sum(sum(cellimg,1),2)~=0);
%D. Sullivan 6/25/13 creation of cell array to save each cell/nuc
%in a random walk.
%         cellimg = cellimg(:,:,keepslices(1)-1:keepslices(end)+1);
%         nucimg = nucimg(:,:,keepslices(1)-1:keepslices(end)+1);

% is this pushed
%D. Sullivan 6/25/13 temporarily create a cellimg and nucimg tiff
%in a temp result folder for the random walk stuff
%D. Sullivan 7/16/ making tempfolder a part of param struct and
%renaming framefolder
%         tempfolder = './temp';

output_folder = [framefolder filesep 'Cellwalk'];
if ~exist( output_folder )
    mkdir( output_folder );
end
cellimg = cellimg(:,:,keepslices(1)-1:keepslices(end)+1);
img2tif(cellimg,[framefolder filesep 'Cellwalk' filesep 'frame' num2str(currframe) '.tif'])

output_folder = [framefolder filesep 'Nucwalk'];
if ~exist( output_folder )
	mkdir( output_folder )
end
nucimg = nucimg(:,:,keepslices(1)-1:keepslices(end)+1);
img2tif(nucimg,[framefolder filesep 'Nucwalk' filesep 'frame' num2str(currframe) '.tif'])

output_folder = [framefolder filesep 'energies'];
if ~exist( output_folder )
	mkdir( output_folder )
end

save([framefolder filesep 'energies' filesep 'walkinfo'...
    num2str(currframe) '.mat'],'energy');
