function primitive = createSBMLstruct(model,currentmodel)
%CREATESBMLSTRUCT This function returns a primitive structure for saving as SBML-Spatial
%
%Inputs: 
%model = Protein model struct from which the temp primitives were generated
%currentmodel = suffix which the primitive temp file contains
%distinguishing it from other models being run. 
%
%Outputs:
%primitive = a struct for primitive object types for input into
%instance2SBML.m to generate a SBML-Spatial instance.
%

%Author: Devin Sullivan September 16, 2013
%Edited: 
%D. Sullivan 9/18/13 - Cleaned up code and added support for multiple
%models
%
% Copyright (C) 2013 Murphy Lab
% Carnegie Mellon University
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published
% by the Free Software Foundation; either version 2 of the License,
% or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
% 02110-1301, USA.
%
% For additional information visit http://murphylab.web.cmu.edu or
% send email to murphy@cmu.edu




%first load temp results 
try 
    load([pwd filesep 'temp' filesep 'primitives' currentmodel '.mat']);
catch 
    error('Unable to locate temp primitives file for the specified model.')
end

primitive = struct;
primitive.name = model.name;
primitive.class = model.class;
primitive.list = struct;
primitive.list.type = struct;
primitive.list.name = struct;
primitive.list.position = struct;
primitive.list.rotation = struct;
primitive.list.scale = struct;

%Determine the ordinal relative to which compartments objects are allowed
%ordinal is indexed at 0 for extracellular 
switch model.cytonuclearflag
    case 'cyto'
        %inside cell but not nuc
        ordinal = 2;
    case 'nuc'
        %inside nuc
        ordinal = 3;
    case 'all'
        %this doesn't really have a proper definition in SBML-Spatial
        %because it allows objects to directly overlap.
        ordinal = 1.5;
    otherwise
        warning('Unknown ordinal specified for protein pattern, defaulting to 2.');
        ordinal = 2;
end

%Loop through each object
for i = 1:size(objsizevec,1)
    %Recognize the primitive type to be used based on the model.type
    switch model.type
        case 'vesicle'
            primitive.list(i).type = 'sphere';
        otherwise
            warning('non-recognized SBML model type. Using blank string.');
            primitive.list.type(i) = '';
    end
    primitive.list(i).name = [model.class num2str(i)];
    primitive.list(i).position = objposvec(i,:).*model.resolution;
    primitive.list(i).rotation = objrotvec(i,:);
    primitive.list(i).scale = objsizevec(i,:).*model.resolution;
    primitive.list(i).ordinal = ordinal;
end